@@ -20,7 +20,7 @@
 # IN THE SOFTWARE.
 
 __author__ = 'Niklas Rosenstein <rosensteinniklas@gmail.com>'
-__version__ = '1.1.0'
+__version__ = '1.2.0'
 __all__ = [
   'Parser',
   'ParserOptions',
@@ -55,13 +55,16 @@ def load_python_modules(
   names. It combines #find_module(), #iter_package_files() and #parse_python_module() in a
   convenient way.
 
-  :param modules: A list of module names to load and parse.
-  :param packages: A list of package names to load and parse.
-  :param files: A list of (module_name, filename) to parse. The filename may also be a
+  # Arguments
+  modules: A list of module names to load and parse.
+  packages: A list of package names to load and parse.
+  files: A list of (module_name, filename) to parse. The filename may also be a
     file-like object. The module name may be None.
-  :param search_path: The Python module search path. Falls back to #sys.path if omitted.
-  :param options: Options for the Python module parser.
-  :return: Iterable of #Module.
+  search_path: The Python module search path. Falls back to #sys.path if omitted.
+  options: Options for the Python module parser.
+
+  # Returns
+  Iterable of #Module.
   """
 
   files = list(files) if files else []
@@ -219,7 +222,7 @@ def discover(directory: str) -> t.Iterable[DiscoveryResult]:
         yield DiscoveryResult.Package(name, os.path.join(directory, name))
 
 
-def format_arglist(args: t.List[Argument]) -> str:
+def format_arglist(args: t.List[Argument], render_type_hints: bool = True) -> str:
   """
   Formats a Python argument list.
   """
@@ -228,10 +231,10 @@ def format_arglist(args: t.List[Argument]) -> str:
 
   for arg in args:
     parts = []
-    if arg.type == Argument.Type.KeywordOnly and '*' not in result:
+    if arg.type == Argument.Type.KEYWORD_ONLY and '*' not in result:
       result.append('*')
     parts = [arg.name]
-    if arg.datatype:
+    if arg.datatype and render_type_hints:
       parts.append(': ' + arg.datatype)
     if arg.default_value:
       if arg.datatype:
@@ -241,9 +244,9 @@ def format_arglist(args: t.List[Argument]) -> str:
       if arg.datatype:
         parts.append(' ')
       parts.append(arg.default_value)
-    if arg.type == Argument.Type.PositionalRemainder:
+    if arg.type == Argument.Type.POSITIONAL_REMAINDER:
       parts.insert(0, '*')
-    elif arg.type == Argument.Type.KeywordRemainder:
+    elif arg.type == Argument.Type.KEYWORD_REMAINDER:
       parts.insert(0, '**')
     result.append(''.join(parts))
 
